@@ -357,22 +357,18 @@ def get_last_branch_changeSet(branch, numberOfChangets):
     output = execute(MoveToMainDirectory + TF_Branches_History.format(branch) + (
         "" if numberOfChangets == None else " /stopafter:{}".format(numberOfChangets)))
 
+    logging.debug("OUTPUT REPR: {}".format(repr(output)))
+
     changeSetList = []
-    # changeSetDict = {}
-    # propertyName = ""
-    # propertyData = ""
-    # needPropertData = False
-    # itemsDict = {}
-    # isItemDict = False
-    # changeSetDict["branch"] = branch
 
     output_list = [item for item in output.split("-" * 79 + '\n\n') if item]
-
+    logging.debug("output_list len: {}".format(len(output_list)))
+    
     for changeset_raw in output_list:
         changeSetDict = {}
         itemsDict = {}
 
-        changeSetDict['branch'] = 'branch'
+        changeSetDict['branch'] = branch
         changeSetDict['items'] = itemsDict
 
         changeset_info_items = changeset_raw.split("\n\n\n\n")
