@@ -45,8 +45,9 @@ def get_last_branch_changeSet(branch, numberOfChangets):
     # itemsDict = {}
     # isItemDict = False
     # changeSetDict["branch"] = branch
+    out = str.join("", list([x for x in output if x in string.printable]))
 
-    output_list = [item for item in output.split("-" * 79 + '\n\n') if item]
+    output_list = [item for item in out.split("-" * 79 + '\n\n') if item]
 
     idx = 0
 
@@ -310,8 +311,8 @@ def wrap_changeset_push_event(arr, rest_api_data, file_tree=None, isBlameRequire
     }
 
     data = to_iso(data)
-    # return json.dumps(data)
-    return data
+    return json.dumps(data)
+    # return data
 
 
 data = wrap_changeset_push_event(get_last_branch_changeSet('branch', numberOfChangets=None), rest_api_data=False)
